@@ -1,6 +1,6 @@
 /*
     license
-    copyright (c) 2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -365,105 +365,154 @@ const gchar *gnu_gpl =
 
 /******************************************************************************
 *                                                                             *
-* 饤󥹴ؿ                                                            *
+* ja:ライセンス関数群                                                         *
 *                                                                             *
 ******************************************************************************/
-/* OKܥ󤬲줿 */
+typedef struct _LicenseDlg     LicenseDlg;
+
+
+struct _LicenseDlg
+{
+  gboolean agree, *display;
+  gint count;
+  guint timer_id;
+  GtkWidget *dialog, *textview, *radio0, *radio1;
+};
+
+
+/* ja:OKボタンが押された */
 static void
-license_dialog_clicked (GtkWidget *widget, GtkWidget *dialog)
+license_dialog_clicked (GtkWidget  *widget,
+                        LicenseDlg *ld)
 {
-	if (gtk_toggle_button_get_active
-		(GTK_TOGGLE_BUTTON (gtk_object_get_user_data (GTK_OBJECT (widget)))))
-		*(gboolean *)gtk_object_get_user_data (GTK_OBJECT (dialog)) = TRUE;
-	gtk_widget_destroy (dialog);
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ld->radio0)))
+    ld->agree = TRUE;
+  gtk_widget_destroy (ld->dialog);
 }
 
 
-/* ESC줿 */
+/* ja:表示領域をチェック */
 static gboolean
-license_dialog_key_press (GtkWidget *widget, GdkEventKey *event,
-															gpointer user_data)
+license_dialog_timeout (LicenseDlg *ld)
 {
-	if (event->keyval == GDK_Escape)
-		gtk_widget_destroy (widget);
-	return FALSE;
+  gint i, st, ed;
+  GtkTextIter iter;
+  GdkRectangle visible_rect;
+
+  gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (ld->textview), &visible_rect);
+  gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (ld->textview), &iter,
+                                            visible_rect.x, visible_rect.y);
+  st = gtk_text_iter_get_line (&iter);
+  gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (ld->textview), &iter,
+    visible_rect.x + visible_rect.width, visible_rect.y + visible_rect.height);
+  ed = gtk_text_iter_get_line (&iter);
+  for (i = st; i <= ed; i++)
+    ld->display[i] = TRUE;
+  for (i =  ld->count - 1; i >= 0; i--)
+    if (!ld->display[i])
+      break;
+  if (i < 0)
+    {
+      gtk_widget_show (ld->radio0);
+      gtk_widget_show (ld->radio1);
+      return FALSE;
+    }
+  return TRUE;
 }
 
 
+/* ja:ダイアログが破棄されるとき */
+static void
+license_dialog_destroy (GtkWidget  *widget,
+                        LicenseDlg *ld)
+{
+  g_source_remove (ld->timer_id);
+  g_free (ld->display);
+  gtk_main_quit ();
+}
+
+
+/* ja:ESCが押された */
+static gboolean
+license_dialog_key_press (GtkWidget   *widget,
+                          GdkEventKey *event,
+                          gpointer     user_data)
+{
+  if (event->keyval == GDK_Escape)
+    gtk_widget_destroy (widget);
+  return FALSE;
+}
+
+
+/*  ja:ライセンス表示                                                       */
 gboolean
 license_dialog (void)
 {
-	gboolean license_clicked_ok = FALSE;
-#ifdef USE_GTK2
-	GtkTextBuffer *buffer;
-#endif /* USE_GTK2 */
-	GtkWidget *dialog, *hbox, *vbox, *scroll;
-	GtkWidget *text, *button0, *button1, *radio0, *radio1;
+  GtkTextBuffer *buffer;
+  GtkWidget *hbox, *vbox, *scroll;
+  GtkWidget *button0, *button1;
+  LicenseDlg ld;
 
-	/* ᥤ󥦥ɥ */
-	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("License"));
-	gtk_window_set_default_size (GTK_WINDOW (dialog),
-					gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
-	gtk_signal_connect_after (GTK_OBJECT (dialog), "key-press-event",
-							GTK_SIGNAL_FUNC (license_dialog_key_press), NULL);
-	gtk_signal_connect (GTK_OBJECT (dialog), "destroy", gtk_main_quit, NULL);
-	gtk_object_set_user_data (GTK_OBJECT (dialog), &license_clicked_ok);
-	/* 륦ɥ */
-	scroll = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
-								GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	/* ƥ */
-#ifdef USE_GTK2
-	text = gtk_text_view_new ();
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text));
-	gtk_text_buffer_set_text (buffer, gnu_gpl, -1);
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
-#else /* not USE_GTK2 */
-	text = gtk_text_new (gtk_scrolled_window_get_hadjustment
-											(GTK_SCROLLED_WINDOW (scroll)),
-							gtk_scrolled_window_get_vadjustment
-											(GTK_SCROLLED_WINDOW (scroll)));
-	gtk_text_freeze (GTK_TEXT (text));
-	gtk_text_insert (GTK_TEXT (text),
-								NULL, NULL, NULL, gnu_gpl, g_strlen (gnu_gpl));
-	gtk_text_thaw (GTK_TEXT (text));
-#endif /* not USE_GTK2 */
-	gtk_container_add (GTK_CONTAINER (scroll), text);
-	/* 饸ܥ */
-	radio0 = gtk_radio_button_new_with_label (NULL, _("I agree."));
-	radio1 = gtk_radio_button_new_with_label_from_widget
-									(GTK_RADIO_BUTTON (radio0), _("I deny."));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1), TRUE);
-	/* ܥ */
-	button0 = gtk_button_new_with_label (_("OK"));
-	button1 = gtk_button_new_with_label (_("Cancel"));
-	gtk_signal_connect (GTK_OBJECT (button0), "clicked",
-							GTK_SIGNAL_FUNC (license_dialog_clicked), dialog);
-	gtk_signal_connect_object (GTK_OBJECT (button1), "clicked",
-					GTK_SIGNAL_FUNC (gtk_widget_destroy), GTK_OBJECT (dialog));
-	gtk_object_set_user_data (GTK_OBJECT (button0), radio0);
-	GTK_WIDGET_SET_FLAGS (button0, GTK_CAN_DEFAULT);
-	GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-	/* ե졼ȥܥå */
-	vbox = gtk_vbox_new (FALSE, SPACING);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
-	gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
-	hbox = gtk_hbox_new (FALSE, SPACING);
-	gtk_box_pack_start (GTK_BOX (hbox),radio0, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox),radio1, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (dialog), vbox);
+  ld.agree = FALSE;
+  /* ja:メインウインドウ */
+  ld.dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (ld.dialog), _("License"));
+  gtk_window_set_default_size (GTK_WINDOW (ld.dialog),
+                                            0, gdk_screen_height () * 2 / 3);
+  g_signal_connect_after (G_OBJECT (ld.dialog), "key-press-event",
+                                G_CALLBACK (license_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (ld.dialog), "destroy",
+                                G_CALLBACK (license_dialog_destroy), &ld);
+  /* ja:テキスト */
+  ld.textview = gtk_text_view_new ();
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (ld.textview));
+  gtk_text_buffer_set_text (buffer, gnu_gpl, -1);
+  gtk_text_view_set_editable (GTK_TEXT_VIEW (ld.textview), FALSE);
+  ld.count = gtk_text_buffer_get_line_count (buffer);
+  ld.display = g_malloc0 (ld.count * sizeof (gboolean));
+  /* ja:スクロールウインドウ */
+  scroll = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  gtk_container_add (GTK_CONTAINER (scroll), ld.textview);
+  /* ja:ラジオボタン */
+  ld.radio0 = gtk_radio_button_new_with_label (NULL, _("I agree."));
+  ld.radio1 = gtk_radio_button_new_with_label_from_widget
+                                (GTK_RADIO_BUTTON (ld.radio0), _("I deny."));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ld.radio1), TRUE);
+  /* ja:ボタン */
+  button0 = gtk_button_new_with_label (_("OK"));
+  button1 = gtk_button_new_with_label (_("Cancel"));
+  g_signal_connect (G_OBJECT (button0), "clicked",
+                        G_CALLBACK (license_dialog_clicked), &ld);
+  g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+                        G_CALLBACK (gtk_widget_destroy), G_OBJECT (ld.dialog));
+  /* ja:フレームとボックス */
+  vbox = gtk_vbox_new (FALSE, SPACING);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
+  hbox = gtk_hbox_new (FALSE, SPACING);
+  gtk_box_pack_start (GTK_BOX (hbox), ld.radio0, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), ld.radio1, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (hbox), button1, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (hbox), button0, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (ld.dialog), vbox);
 
-	/* ɽ */
-	gtk_widget_grab_focus (button1);
+  /* ja:表示 */
+  gtk_widget_grab_focus (button1);
 
-	gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-	gtk_grab_add (dialog);
-	gtk_widget_show_all (dialog);
-	gtk_main ();
+  gtk_window_set_policy (GTK_WINDOW (ld.dialog), FALSE, TRUE, FALSE);
+  gtk_grab_add (ld.dialog);
+  gtk_widget_show (button0);
+  gtk_widget_show (button1);
+  gtk_widget_show (scroll);
+  gtk_widget_show (ld.textview);
+  gtk_widget_show (hbox);
+  gtk_widget_show (vbox);
+  gtk_widget_show (ld.dialog);
+  ld.timer_id = g_timeout_add (100, (GSourceFunc)license_dialog_timeout, &ld);
+  gtk_main ();
 
-	return license_clicked_ok;
+  return ld.agree;
 }
