@@ -33,6 +33,7 @@
 #include "misc/fileio.h"
 #include "misc/misc.h"
 #include "misc/misc_conf.h"
+#include "misc/misc_history.h"
 #include "misc/misc_mdi.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
@@ -55,7 +56,7 @@ command_new (gpointer   callback_data,
 }
 
 
-#if ! defined G_OS_WIN32 && ! defined USE_GTK24
+#if ! defined G_OS_WIN32 && ! GTK_CHECK_VERSION(2,4,0)
 static void
 command_open_ok (GtkWidget *widget,
                  GtkWidget *dialog)
@@ -67,7 +68,7 @@ command_open_ok (GtkWidget *widget,
                                                 (GTK_FILE_SELECTION (dialog)));
   gtk_widget_destroy (dialog);
 }
-#endif /* not defined G_OS_WIN32 and not defined USE_GTK24 */
+#endif /* not defined G_OS_WIN32 and not GTK_CHECK_VERSION(2,4,0) */
 
 
 void
@@ -76,9 +77,9 @@ command_open (gpointer   callback_data,
               GtkWidget *widget)
 {
   gchar *file = NULL, *path;
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
   gint i;
-#endif /* USE_GTK24 or G_OS_WIN32 */
+#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
 #ifdef G_OS_WIN32
   gchar *filter = NULL;
   gint length, pos = 0;
@@ -150,7 +151,7 @@ command_open (gpointer   callback_data,
 #else /* not G_OS_WIN32 */
   GtkWidget *dialog;
 
-# ifdef USE_GTK24
+# if GTK_CHECK_VERSION(2,4,0)
   GtkFileFilter *filter;
 
   dialog = gtk_file_chooser_dialog_new (_("Open"),
@@ -184,7 +185,7 @@ command_open (gpointer   callback_data,
       findex = (gint)g_object_get_data (G_OBJECT (filter), "user_data");
     }
   gtk_widget_destroy (dialog);
-# else /* not USE_GTK24 */
+# else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog = gtk_file_selection_new (_("Open"));
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
@@ -204,7 +205,7 @@ command_open (gpointer   callback_data,
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
-# endif /* not USE_GTK24 */
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
 #endif /* not G_OS_WIN32 */
   if (file)
     {
@@ -261,9 +262,9 @@ command_saveas (gpointer   callback_data,
                 GtkWidget *widget)
 {
   gchar *file = NULL, *path;
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
   gint i;
-#endif /* USE_GTK24 or G_OS_WIN32 */
+#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
 #ifdef G_OS_WIN32
   gchar *filter = NULL;
   gint length, pos = 0;
@@ -335,7 +336,7 @@ command_saveas (gpointer   callback_data,
 #else /* not G_OS_WIN32 */
   GtkWidget *dialog;
 
-# ifdef USE_GTK24
+# if GTK_CHECK_VERSION(2,4,0)
   GtkFileFilter *filter;
 
   dialog = gtk_file_chooser_dialog_new (_("Save As"),
@@ -370,7 +371,7 @@ command_saveas (gpointer   callback_data,
       findex = (gint)g_object_get_data (G_OBJECT (filter), "user_data");
     }
   gtk_widget_destroy (dialog);
-# else /* not USE_GTK24 */
+# else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog = gtk_file_selection_new (_("Save As"));
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
@@ -390,7 +391,7 @@ command_saveas (gpointer   callback_data,
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
-# endif /* not USE_GTK24 */
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
 #endif /* not G_OS_WIN32 */
   if (file)
     {
@@ -420,7 +421,7 @@ command_saveas (gpointer   callback_data,
           delete_list (&tmaid->undo);
           delete_list (&tmaid->redo);
           set_menu_bar (tmaid);
-          file_set_history (file);
+          misc_history_add_file (MISC_HISTORY (history), file);
         }
       g_free (text);
       g_free (file);
@@ -1063,24 +1064,13 @@ static void
 command_conf_ok (GtkWidget *widget,
                  GtkWidget *dialog)
 {
-  gint i;
-  GList *glist;
-  GtkWidget *menu_shell;
-
-  history = misc_conf_get_history (MISC_CONF (dialog));
+  misc_history_set_num (MISC_HISTORY (history),
+                                misc_conf_get_history (MISC_CONF (dialog)));
   newfile = misc_conf_get_newfile (MISC_CONF (dialog));
   second = misc_conf_get_second (MISC_CONF (dialog));
   misc_conf_get_size (MISC_CONF (dialog), &def_width, &def_height);
   n_pos = misc_conf_get_tab (MISC_CONF (dialog));
   gtk_widget_destroy (dialog);
-  /* ja:履歴の整理 */
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-  for (i = g_list_length (glist) - 3;
-                            i > history- (history == 0) + MENUFILE - 2; i--)
-    gtk_container_remove (GTK_CONTAINER (menu_shell),
-                                                g_list_nth_data (glist, i));
-  g_list_free (glist);
   /* ja:ノートの位置 */
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
 }
@@ -1100,7 +1090,8 @@ command_conf (gpointer   callback_data,
                             "clicked", G_CALLBACK (command_conf_ok), dialog);
   g_signal_connect_swapped (G_OBJECT (MISC_CONF (dialog)->cancel_button),
             "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  misc_conf_set_history (MISC_CONF(dialog), history);
+  misc_conf_set_history (MISC_CONF(dialog),
+                                misc_history_get_num (MISC_HISTORY (history)));
   misc_conf_set_newfile (MISC_CONF(dialog), newfile);
   misc_conf_set_second (MISC_CONF(dialog), second);
   misc_conf_set_size (MISC_CONF(dialog), def_width, def_height);
