@@ -27,65 +27,10 @@
 #include "misc/charuty.h"
 #include "misc/fileio.h"
 #include "misc/misc.h"
+#include "misc/misc_history.h"
 #include "misc/misc_mdi.h"
 
 
-/******************************************************************************
-*                                                                             *
-* ja:ファイル関数群                                                           *
-*                                                                             *
-******************************************************************************/
-/*  ja:ファイルの履歴に加える
-    file,ファイル名                                                         */
-void
-file_set_history (const gchar *file)
-{
-  gchar *label;
-  gint i, count;
-  GList *glist;
-  GtkWidget *menu_shell, *menu_item;
-
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-  count = g_list_length (glist);
-  for (i = 0; i < count - MENUFILE - 1; i++)
-    {
-      menu_item = g_list_nth_data (glist, i + MENUFILE - 1);
-      label = g_object_get_data (G_OBJECT (menu_item), "user_data");
-      if (g_strfilecmp (label, file) == 0)
-        {
-          gtk_container_remove (GTK_CONTAINER (menu_shell), menu_item);
-          break;
-        }
-    }
-  g_list_free (glist);
-  if (i >= history)
-    {
-      glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-      gtk_container_remove (GTK_CONTAINER (menu_shell),
-                        g_list_nth_data (glist, MENUFILE + history + 1 - 3));
-      g_list_free (glist);
-    }
-  if (count <= MENUFILE)
-    {
-      menu_item = gtk_menu_item_new ();
-      gtk_menu_insert (GTK_MENU (menu_shell), menu_item, MENUFILE - 2);
-        gtk_widget_show (menu_item);
-    }
-  label = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
-  menu_item = gtk_menu_item_new_with_label (label);
-  g_free (label);
-  label = g_strdup (file);
-  g_signal_connect (G_OBJECT (menu_item), "activate",
-                            G_CALLBACK (signal_activate_menu_history), label);
-  g_signal_connect (G_OBJECT (menu_item), "destroy",
-                            G_CALLBACK (signal_destroy_menu_history), label);
-  g_object_set_data (G_OBJECT (menu_item), "user_data", label);
-  gtk_menu_insert (GTK_MENU (menu_shell), menu_item, MENUFILE - 1);
-  gtk_widget_show (menu_item);
-}
-
-
 /******************************************************************************
 *                                                                             *
 * ja:ファイル入力関数群                                                       *
@@ -553,8 +498,8 @@ file_open_edit (const gchar *file)
   rc.height = tmaid->font_height;
   gtk_im_context_set_cursor_location (tmaid->im_context, &rc);
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
-  if (file && history > 0 && fileio_isfile (file))
-    file_set_history (filename);
+  if (file && fileio_isfile (file))
+    misc_history_add_file (MISC_HISTORY (history), file);
   g_free (filename);
   /* ja:右マージン */
   if (tmaid->ft.limit)
