@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,10 +26,10 @@
 #include "misc/misc.h"
 
 
-gboolean find_arrow=TRUE;                   /* ja:検索の設定 */
-gboolean find_ignorecase=FALSE;             /* ja:検索の設定 */
+gboolean find_arrow = TRUE;                 /* ja:検索の設定 */
+gboolean find_ignorecase = FALSE;           /* ja:検索の設定 */
 gchar *find_text[32];                       /* ja:検索する文字列 */
-gint find_num=0;                            /* ja:登録されている検索文字列 */
+gint find_num = 0;                          /* ja:登録されている検索文字列 */
 
 
 /******************************************************************************
@@ -367,8 +367,13 @@ static void
 find_dialog_clicked (GtkWidget  *widget,
                      FindString *fd)
 {
+#if GTK_CHECK_VERSION(2,4,0)
+  fd->text = g_strdup
+                    (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child)));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   fd->text = g_strdup
                 (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry)));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   fd->ignorecase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
   fd->arrow = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1));
   gtk_widget_destroy (dialog);
@@ -415,7 +420,9 @@ gboolean
 find_dialog (FindString *fd)
 {
   gint i;
+#if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   GtkWidget *radio0, *button0, *button1, *frame0, *frame1, *hbox, *tbox, *vbox;
 
   /* ja:メインウインドウ */
@@ -438,6 +445,21 @@ find_dialog (FindString *fd)
   check = gtk_check_button_new_with_mnemonic (_("Enable _Case"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), fd->ignorecase);
   /* ja:コンボボックス */
+#if GTK_CHECK_VERSION(2,4,0)
+  combo = gtk_combo_box_entry_new_text ();
+  for (i = 0; i < find_num; i++)
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), find_text[i]);
+  if (find_num > 0)
+    {
+      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), find_text[0]);
+      gtk_editable_select_region (GTK_EDITABLE (GTK_BIN (combo)->child),
+                                                                        0, -1);
+    }
+  g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "activate",
+                                        G_CALLBACK (find_dialog_activate), fd);
+  g_signal_connect (G_OBJECT (GTK_BIN (combo)->child), "changed",
+                                    G_CALLBACK (find_dialog_changed), button0);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; i < find_num; i++)
     glist = g_list_append (glist, find_text[i]);
   combo = gtk_combo_new ();
@@ -449,11 +471,13 @@ find_dialog (FindString *fd)
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), find_text[0]);
       gtk_editable_select_region (GTK_EDITABLE (GTK_COMBO (combo)->entry),
                                                                         0, -1);
+      g_list_free (glist);
     }
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "activate",
                                         G_CALLBACK (find_dialog_activate), fd);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
                                     G_CALLBACK (find_dialog_changed), button0);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_mnemonic (NULL, _("_Up"));
   radio1 = gtk_radio_button_new_with_mnemonic_from_widget
@@ -490,9 +514,15 @@ find_dialog (FindString *fd)
   gtk_container_add (GTK_CONTAINER (dialog), tbox);
 
   /* ja:表示 */
+#if GTK_CHECK_VERSION(2,4,0)
+  gtk_widget_set_sensitive (button0,
+    g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child))) > 0);
+  gtk_widget_grab_focus (GTK_BIN (combo)->child);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_widget_set_sensitive (button0,
     g_strlen (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry))) > 0);
   gtk_widget_grab_focus (GTK_COMBO (combo)->entry);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   find_clicked_ok = FALSE;
 
   gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
