@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ファイルタイプダイアログ関数群                                           *
@@ -33,4 +38,9 @@ void
 format_dialog (void);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
