@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,9 @@
 #include "general.h"
 #include "sigfile.h"
 #include "toolbar.h"
+#include "misc/charuty.h"
 #include "misc/misc.h"
+#include "misc/misc_mdi.h"
 
 
 /******************************************************************************
@@ -130,11 +132,12 @@ draw_caret (TmaidWindow *tmaid,
 void
 set_menu_bar (TmaidWindow *tmaid)
 {
-  GList *glist;
-  GtkWidget *menu;
-
   if (tmaid)
     {
+      gboolean created;
+
+      created = misc_mdi_get_created (MISC_MDI (mdi),
+                        misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid));
       gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
             (gtk_item_factory_get_widget (ifactory_menu, "<main>/Edit"))),
                                                                         TRUE);
@@ -148,7 +151,7 @@ set_menu_bar (TmaidWindow *tmaid)
       gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Save As..."), TRUE);
       gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload..."), !tmaid->create);
+                                "<main>/File/Reload..."), !created);
       gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Print..."), TRUE);
       gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
@@ -211,11 +214,6 @@ set_menu_bar (TmaidWindow *tmaid)
       gtk_widget_set_sensitive (toolbar_items[16].item, FALSE);
       gtk_widget_set_sensitive (toolbar_items[17].item, FALSE);
     }
-  menu = gtk_item_factory_get_widget (ifactory_menu, "<main>/Window");
-  glist = gtk_container_children (GTK_CONTAINER (menu));
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU (menu)),
-                                                    g_list_length (glist) > 0);
-  g_list_free (glist);
 }
 
 
@@ -577,11 +575,15 @@ modify_margin (TmaidWindow *tmaid)
 gboolean
 prompt_close (TmaidWindow *tmaid)
 {
-  if (tmaid->edit)
+  gint page;
+
+  page = misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid);
+  if (misc_mdi_get_edited (MISC_MDI (mdi), page))
     {
       gchar *text, *utf8str;
 
-      utf8str = g_filename_to_utf8 (tmaid->file, -1, NULL, NULL, NULL);
+      utf8str = g_filename_to_utf8
+            (misc_mdi_get_file (MISC_MDI (mdi), page), -1, NULL, NULL, NULL);
       text = g_strdup_printf (_("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
       switch (misc_message_box ("Text maid", text, 0,
@@ -589,35 +591,17 @@ prompt_close (TmaidWindow *tmaid)
         {
           case 0:
             {
-              GtkWidget *child;
+              gint page_num;
 
-              child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
-                    gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)));
-              if (g_object_get_data (G_OBJECT (child), "user_data") != tmaid)
-                {
-                  gint i;
-                  GList *glist;
-
-                  glist = gtk_container_children (GTK_CONTAINER (notebook));
-                  for (i = g_list_length (glist) - 1; i >= 0; i--)
-                    if (g_object_get_data (G_OBJECT (g_list_nth_data
-                                            (glist, i)), "user_data") == tmaid)
-                      {
-                        gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook),
-                                                                            i);
-                        break;
-                      }
-                  g_list_free (glist);
-                }
+              page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
+              if (page != page_num)
+                gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page);
               else
-                {
-                  child = NULL;
-                }
+                page_num = -1;
               command_save (NULL, 0, NULL);
-              if (child)
-                gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook),
-                    gtk_notebook_page_num (GTK_NOTEBOOK (notebook), child));
-              if (!tmaid->edit)
+              if (page_num >= 0)
+                gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
+              if (!misc_mdi_get_edited (MISC_MDI (mdi), page))
                 break;
             }
           case 2:
@@ -631,20 +615,32 @@ prompt_close (TmaidWindow *tmaid)
 }
 
 
-/*  ja:タブの編集済みマークの変更
-      tmaid,ウインドウ情報
-    is_edit,TRUE:編集済み,FALSE:未編集                                      */
+/*  ja:キャラクターセットを置換する
+    charlist,置換するキャラクターセット
+       ft_id,ファイルタイプのID(-1:追加なし)                                */
 void
-tmaid_change_edit (TmaidWindow *tmaid,
-                   gboolean     is_edit)
+charlist_renewal_all (const gchar *charlist,
+                      const gint   ft_id)
 {
-  if (tmaid->edit != is_edit)
+  gchar *charset;
+  gint i;
+
+  for (i = 0; i < ftnum; i++)
     {
-      tmaid->edit = is_edit;
-      if (is_edit)
-        gtk_widget_show (tmaid->mark);
-      else
-        gtk_widget_hide (tmaid->mark);
+      charset = ftype[i].ft_id == ft_id
+                                ? charuty_append (ftype[i].charset, charlist)
+                                : charuty_rename (ftype[i].charset, charlist);
+      g_free (ftype[i].charset);
+      ftype[i].charset = charset;
+    }
+  for (i = misc_mdi_get_n_pages (MISC_MDI (mdi)) - 1; i >= 0; i--)
+    {
+      TmaidWindow *tmaid;
+
+      tmaid = misc_mdi_get_data (MISC_MDI (mdi), i);
+      charset = charuty_rename (tmaid->ft.charset, charlist);
+      g_free (tmaid->ft.charset);
+      tmaid->ft.charset = charset;
     }
 }
 
@@ -717,7 +713,8 @@ margin_operation (TmaidWindow *tmaid)
       p = p->next;
     }
   tmaid->ft.limit = limit;
-  tmaid_change_edit (tmaid, TRUE);
+  misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
   tmaid->cursor.x = tmaid->cursor.y = tmaid->top.x = tmaid->top.y = 0;
   tmaid->select.x = -1;
   misc_set_scroll_bar (tmaid->hscroll,
@@ -782,7 +779,8 @@ tab_operation (TmaidWindow *tmaid)
           }
       p = p->next;
     }
-  tmaid_change_edit (tmaid, TRUE);
+  misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
   tmaid->select.x = -1;
   set_menu_bar (tmaid);
   gtk_widget_draw (tmaid->drawing, NULL);
