@@ -22,6 +22,9 @@
 #include "charset.h"
 #include "edit.h"
 #include "print.h"
+#ifndef G_OS_WIN32
+# include "misc/fileio.h"
+#endif /* not G_OS_WIN32 */
 #include "misc/misc.h"
 #ifdef G_OS_WIN32
 # include "misc/misc_mdi.h"
@@ -39,7 +42,8 @@ PrintConfig printer;                        /* ja:印刷の設定 */
 ******************************************************************************/
 #ifdef G_OS_WIN32
 BOOL CALLBACK
-PrintProc (HDC hdc, int nError)
+PrintProc (HDC hdc,
+           int nError)
 {
   return userbreak;
 }
@@ -381,8 +385,8 @@ static struct
 {
   gchar *name;
   const gint width, height;
-} paper[]={ {"A3", 840, 1188}, {"A4", 594, 840}, {"A5", 420, 594},
-            {"B4", 730, 1030}, {"B5", 515, 730}, {NULL, 0, 0}};
+} paper[] = { {"A3", 840, 1188}, {"A4", 594, 840}, {"A5", 420, 594},
+              {"B4", 730, 1030}, {"B5", 515, 730}, {NULL, 0, 0}};
 #endif /* not G_OS_WIN32 */
 
 
@@ -477,22 +481,33 @@ static void
 print_dialog_changed_combo (GtkWidget *widget,
                             gpointer   user_data)
 {
+# if GTK_CHECK_VERSION(2,4,0)
+  gchar *name;
+# else /* not GTK_CHECK_VERSION(2,4,0) */
   const gchar *name;
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
   gint i;
 
-  name = gtk_entry_get_text (GTK_ENTRY (widget));
-  for (i = 0; paper[i].name != NULL; i++)
-    if (!g_strcmp (paper[i].name, name))
-      break;
-  if (!paper[i].name)
-    {
-      /* ja:ユーザー設定 */
-      gtk_widget_set_sensitive (label3, TRUE);
-      gtk_widget_set_sensitive (label4, TRUE);
-      gtk_widget_set_sensitive (spin2, TRUE);
-      gtk_widget_set_sensitive (spin3, TRUE);
-    }
+# if GTK_CHECK_VERSION(2,6,0)
+  name = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+# elif GTK_CHECK_VERSION(2,4,0)
+  GtkTreeIter iter;
+
+  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter))
+    gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (widget)),
+                                                        &iter, 0, &name, -1);
   else
+    name = NULL;
+# else /* not GTK_CHECK_VERSION(2,4,0) */
+  name = gtk_entry_get_text (GTK_ENTRY (widget));
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
+  for (i = 0; paper[i].name; i++)
+    if (g_strcmp (paper[i].name, name) == 0)
+      break;
+# if GTK_CHECK_VERSION(2,4,0)
+  g_free (name);
+# endif /* GTK_CHECK_VERSION(2,4,0) */
+  if (paper[i].name)
     {
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin2), paper[i].width);
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin3), paper[i].height);
@@ -501,6 +516,14 @@ print_dialog_changed_combo (GtkWidget *widget,
       gtk_widget_set_sensitive (spin2, FALSE);
       gtk_widget_set_sensitive (spin3, FALSE);
     }
+  else
+    {
+      /* ja:ユーザー設定 */
+      gtk_widget_set_sensitive (label3, TRUE);
+      gtk_widget_set_sensitive (label4, TRUE);
+      gtk_widget_set_sensitive (spin2, TRUE);
+      gtk_widget_set_sensitive (spin3, TRUE);
+    }
 }
 #endif /* not G_OS_WIN32 */
 
@@ -564,6 +587,7 @@ print_dialog_clicked_ok (GtkWidget   *widget,
 
 
 #ifndef G_OS_WIN32
+# if ! GTK_CHECK_VERSION(2,4,0)
 /* ja:ファイルの参照でOKボタンが押された */
 static void
 print_open_ok (GtkWidget *widget,
@@ -576,6 +600,7 @@ print_open_ok (GtkWidget *widget,
                                         (GTK_FILE_SELECTION (dialog_open)));
   gtk_widget_destroy (dialog_open);
 }
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
 
 
 /* ja:参照ボタンが押された */
@@ -586,20 +611,50 @@ print_dialog_clicked_file (GtkWidget   *widget,
   gchar *file = NULL;
   GtkWidget *dialog_open;
 
+# if GTK_CHECK_VERSION(2,4,0)
+  dialog_open = gtk_file_chooser_dialog_new (_("Save As"),
+                        GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
+                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        NULL);
+  file = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (entry1)),
+                                                        -1, NULL, NULL, NULL);
+  if (fileio_isfile (file))
+    {
+      gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog_open), file);
+    }
+  else
+    {
+      gchar *dir, *path;
+
+      dir = g_path_get_dirname (file);
+      path = fileio_get_full_path (dir);
+      g_free (dir);
+      if (fileio_isfile (path))
+        gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog_open),
+                                                                        path);
+      g_free (path);
+    }
+  g_free (file);
+  file = gtk_dialog_run (GTK_DIALOG (dialog_open)) == GTK_RESPONSE_ACCEPT
+    ? gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog_open)) : NULL;
+  gtk_widget_destroy (dialog_open);
+# else /* not GTK_CHECK_VERSION(2,4,0) */
   dialog_open = gtk_file_selection_new (_("Save As"));
   g_signal_connect (G_OBJECT (dialog_open), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
   g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog_open)->ok_button),
-                            "clicked",G_CALLBACK (print_open_ok), dialog_open);
+                        "clicked", G_CALLBACK (print_open_ok), dialog_open);
   g_signal_connect_swapped
-            (G_OBJECT (GTK_FILE_SELECTION (dialog_open)->cancel_button),
-            "clicked",G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog_open));
+        (G_OBJECT (GTK_FILE_SELECTION (dialog_open)->cancel_button),
+        "clicked", G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog_open));
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (dialog_open),
                                     gtk_entry_get_text (GTK_ENTRY (entry1)));
   g_object_set_data (G_OBJECT (dialog_open), "user_data", &file);
   gtk_widget_show (dialog_open);
   gtk_grab_add (dialog_open);
   gtk_main ();
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
   if (file)
     {
       gtk_entry_set_text (GTK_ENTRY (entry1), file);
@@ -669,7 +724,9 @@ print_dialog (PrintConfig *prncfg)
   GtkWidget *button2, *label0, *hbox0, *hbox1, *vbox;
 #ifndef G_OS_WIN32
   gint i;
+# if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist = NULL;
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
   GtkWidget *combo, *frame0, *frame1, *label5, *label6, *label7, *label8;
 # ifdef G_OS_UNIX
   GtkWidget *radio1;
@@ -838,8 +895,16 @@ print_dialog (PrintConfig *prncfg)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label9), entry1);
 # endif /* not G_OS_UNIX */
   /* ja:コンボボックス */
+# if GTK_CHECK_VERSION(2,4,0)
+  combo = gtk_combo_box_new_text ();
   for (i = 0; paper[i].name; i++)
-    glist = g_list_append (glist,paper[i].name);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), paper[i].name);
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("User Define"));
+  g_signal_connect (G_OBJECT (combo), "changed",
+                                G_CALLBACK (print_dialog_changed_combo), NULL);
+# else /* not GTK_CHECK_VERSION(2,4,0) */
+  for (i = 0; paper[i].name; i++)
+    glist = g_list_append (glist, paper[i].name);
   glist = g_list_append (glist, _("User Define"));
   combo = gtk_combo_new ();
   gtk_combo_set_popdown_strings (GTK_COMBO (combo), glist);
@@ -847,11 +912,20 @@ print_dialog (PrintConfig *prncfg)
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
                                 G_CALLBACK (print_dialog_changed_combo), NULL);
+  g_list_free (glist);
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
   for (i = 0; paper[i].name; i++)
     if (paper[i].width == prncfg->width && paper[i].height == prncfg->height)
       break;
+# if GTK_CHECK_VERSION(2,4,0)
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), i);
+# else /* not GTK_CHECK_VERSION(2,4,0) */
   if (paper[i].name)
     gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), paper[i].name);
+  else
+    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry),
+                                                            _("User Define"));
+# endif /* not GTK_CHECK_VERSION(2,4,0) */
 
   /* ja:フレームとボックス */
   frame0 = gtk_frame_new (_("Paper"));
