@@ -140,7 +140,10 @@ property_change (TmaidWindow *tmaid,
 *                                                                             *
 ******************************************************************************/
 static gboolean property_clicked_ok, color_list[12];
-static gchar *charset_list, *font_name;
+static gchar *charset_list;
+#if ! GTK_CHECK_VERSION(2,4,0)
+static gchar *font_name;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkListStore *store;
@@ -151,6 +154,9 @@ static GtkWidget *check5, *check6, *check7, *check8, *check9;
 static GtkWidget *check10, *check11, *check12, *check13, *check14, *check15;
 static GtkWidget *radio0, *radio1, *radio2, *radio3, *radio4, *radio5, *radio6;
 static GtkWidget *tview, *entry0, *entry1, *label, *spin0, *spin1;
+#if GTK_CHECK_VERSION(2,4,0)
+static GtkWidget *button2;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
 
 /* ja:OKボタンの表示/非表示を判定 */
@@ -326,6 +332,7 @@ property_dialog_clicked_charlist (GtkWidget *widget,
 }
 
 
+#if ! GTK_CHECK_VERSION(2,4,0)
 /* ja:フォントの設定でOKが押されたとき */
 static void
 property_dialog_clicked_font_ok (GtkWidget *widget,
@@ -368,6 +375,7 @@ property_dialog_clicked_font (GtkWidget *widget,
   gtk_grab_add (dialog_font);
   gtk_main ();
 }
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
 
 /* ja:ファイルタイプボタンが押された */
@@ -425,17 +433,26 @@ property_dialog_clicked_ftype (GtkWidget *widget,
           gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ftype[pos].hexcase
                                                     ? radio5 : radio6), TRUE);
           if (ftype[pos].crlf < 3)
+#if GTK_CHECK_VERSION(2,4,0)
+            gtk_combo_box_set_active (GTK_COMBO_BOX (combo), ftype[pos].crlf);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
             gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry),
                     gtk_label_get_text (GTK_LABEL (gtk_bin_get_child (GTK_BIN
                     (g_list_nth_data (gtk_container_get_children
                         (GTK_CONTAINER (GTK_COMBO (combo)->list)),
                                                 ftype[pos].crlf))))));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
           gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin0),
                                                             ftype[pos].margin);
           gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin1), ftype[pos].tab);
           g_memmove (gdk_color, ftype[pos].color, sizeof (GdkColor) * 12);
+#if GTK_CHECK_VERSION(2,4,0)
+          gtk_font_button_set_font_name (GTK_FONT_BUTTON (button2),
+                                                        ftype[pos].font_name);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
           g_free (font_name);
           font_name = g_strdup (ftype[pos].font_name);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
           gtk_widget_set_sensitive (button4, TRUE);
         }
       else
@@ -497,6 +514,9 @@ property_dialog_clicked_ok (GtkWidget *widget,
     ft->writemode = 0;
   ft->hexcase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio5));
   if (combo)
+#if GTK_CHECK_VERSION(2,4,0)
+    ft->crlf = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
     {
       const gchar *text;
       GList *glist;
@@ -504,13 +524,14 @@ property_dialog_clicked_ok (GtkWidget *widget,
       text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
       glist = gtk_container_children (GTK_CONTAINER (GTK_COMBO (combo)->list));
       for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
-        if (!g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
-                        (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), text))
+        if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), text) == 0)
           break;
       g_list_free (glist);
       if (ft->crlf < 0)
         ft->crlf = 0;
     }
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   g_free (ft->charset);
   if (charset)
     ft->charset = misc_charset_get_charset (MISC_CHARSET (charset));
@@ -521,8 +542,13 @@ property_dialog_clicked_ok (GtkWidget *widget,
     }
   g_memmove (ft->color, gdk_color, sizeof (GdkColor) * 12);
   g_free (ft->font_name);
+#if GTK_CHECK_VERSION(2,4,0)
+  ft->font_name = g_strdup (gtk_font_button_get_font_name
+                                                (GTK_FONT_BUTTON (button2)));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   ft->font_name = font_name;
   font_name = NULL;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_widget_destroy (dialog);
   property_clicked_ok = TRUE;
 }
@@ -534,7 +560,7 @@ property_dialog_activate (GtkWidget *widget,
                           FileType  *ft)
 {
   if (GTK_WIDGET_IS_SENSITIVE (button4))
-    property_dialog_clicked_ok(widget,ft);
+    property_dialog_clicked_ok (widget, ft);
 }
 
 
@@ -558,14 +584,19 @@ property_dialog (FileType *ft)
 {
   gchar *xpm[18];
   gint i;
+#if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   GtkCellRenderer *renderer;
   GtkTreeIter iter;
   GtkTreeSelection *select;
   GtkTreeViewColumn *column;
-  GtkWidget *button2, *button3, *button5, *scroll, *frame_label;
+  GtkWidget *button3, *button5, *scroll, *frame_label;
   GtkWidget *hbox, *tbox, *vbox;
   GtkWidget *frame0, *frame1, *frame2, *frame3, *frame4, *frame5, *frame6;
+#if ! GTK_CHECK_VERSION(2,4,0)
+  GtkWidget *button2;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   gchar *color_name[12] = {
             N_("Foreground"), N_("Background"), N_("Control Code"),
             N_("Full Width Space"), N_("Return Code"), N_("Tab Under Line"),
@@ -583,13 +614,22 @@ property_dialog (FileType *ft)
                                             G_CALLBACK (gtk_main_quit), NULL);
   /* ja:ボタン */
   button0 = gtk_button_new_with_label (_("Palette"));
+#if GTK_CHECK_VERSION(2,4,0)
+  button2 = gtk_font_button_new_with_font (ft->font_name);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   button2 = gtk_button_new_with_mnemonic (_("_Font"));
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   button4 = gtk_button_new_with_label (_("OK"));
   button5 = gtk_button_new_with_label (_("Cancel"));
   g_signal_connect (G_OBJECT (button0), "clicked",
                             G_CALLBACK (property_dialog_clicked_color), NULL);
+#if GTK_CHECK_VERSION(2,4,0)
+  g_signal_connect (G_OBJECT (button2), "font-set",
+                            G_CALLBACK (property_dialog_ok_sensitive), NULL);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   g_signal_connect (G_OBJECT (button2), "clicked",
                             G_CALLBACK (property_dialog_clicked_font), NULL);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   g_signal_connect (G_OBJECT (button4), "clicked",
                                 G_CALLBACK (property_dialog_clicked_ok), ft);
   g_signal_connect_swapped (G_OBJECT (button5), "clicked",
@@ -695,20 +735,33 @@ property_dialog (FileType *ft)
       check13 = check14 = check15 = NULL;
     }
   /* ja:コンボボックス */
+#if GTK_CHECK_VERSION(2,4,0)
+  combo = gtk_combo_box_new_text ();
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "CR+LF");
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "CR");
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "LF");
+  if (ft->text && ft->ext)
+    gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Auto"));
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), ft->crlf);
+  g_signal_connect (G_OBJECT (combo), "changed",
+                            G_CALLBACK (property_dialog_ok_sensitive), NULL);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   glist = g_list_append (NULL, "CR+LF");
   glist = g_list_append (glist, "CR");
   glist = g_list_append (glist, "LF");
   if (ft->text && ft->ext)
     glist = g_list_append (glist, _("Auto"));
-  combo = gtk_combo_new();
+  combo = gtk_combo_new ();
   gtk_combo_set_popdown_strings (GTK_COMBO (combo), glist);
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry),
                                             g_list_nth_data (glist, ft->crlf));
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "activate",
                                     G_CALLBACK (property_dialog_activate), ft);
-  g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry),"changed",
+  g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
                             G_CALLBACK (property_dialog_ok_sensitive), NULL);
+  g_list_free (glist);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:文字符号化方式 */
   if (!ft->text && !ft->ext)
     {
@@ -718,7 +771,7 @@ property_dialog (FileType *ft)
       misc_charset_set_charset (MISC_CHARSET (charset), ft->charset);
       g_signal_connect (G_OBJECT (charset), "activate",
                                     G_CALLBACK (property_dialog_activate), ft);
-      g_signal_connect (G_OBJECT (charset), "changed",
+      g_signal_connect (G_OBJECT (charset), "edited",
                             G_CALLBACK (property_dialog_ok_sensitive), NULL);
     }
   else
@@ -951,8 +1004,12 @@ property_dialog (FileType *ft)
   frame_label = gtk_frame_get_label_widget (GTK_FRAME (frame6));
   gtk_label_set_text_with_mnemonic (GTK_LABEL (frame_label),
                                                     _("Character _Encoding"));
+#if GTK_CHECK_VERSION(2,4,0)
+  gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label), combo);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (frame_label),
                                                     GTK_COMBO (combo)->entry);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, FALSE, 0);
@@ -1029,7 +1086,9 @@ property_dialog (FileType *ft)
   ft_id = ft->ft_id;
   g_memmove (gdk_color, ft->color, sizeof (GdkColor) * 12);
   charset_list = button1 ? g_strdup (ft->charset) : NULL;
+#if ! GTK_CHECK_VERSION(2,4,0)
   font_name = g_strdup (ft->font_name);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   property_clicked_ok = FALSE;
 
   gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
@@ -1038,7 +1097,9 @@ property_dialog (FileType *ft)
   gtk_main ();
 
   g_free (charset_list);
+#if ! GTK_CHECK_VERSION(2,4,0)
   g_free (font_name);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
   return property_clicked_ok;
 }
