@@ -45,12 +45,17 @@ static void
 reload_dialog_clicked (GtkWidget *widget,
                        FileType  *ft)
 {
+#if ! GTK_CHECK_VERSION(2,4,0)
   const gchar *str;
   GList *glist;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
 
   g_free (ft->charset);
   ft->html = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check0));
   ft->esc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check1));
+#if GTK_CHECK_VERSION(2,4,0)
+  ft->crlf = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   str = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
   glist = gtk_container_children (GTK_CONTAINER (GTK_COMBO (combo)->list));
   for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
@@ -60,6 +65,7 @@ reload_dialog_clicked (GtkWidget *widget,
   g_list_free (glist);
   if (ft->crlf < 0)
     ft->crlf = 0;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   ft->charset = misc_charset_get_charset (MISC_CHARSET (charset));
   gtk_widget_destroy (dialog);
   reload_clicked_ok = TRUE;
@@ -97,7 +103,9 @@ reload_dialog (FileType    *ft,
                const gchar *text)
 {
   gint i;
+#if ! GTK_CHECK_VERSION(2,4,0)
   GList *glist;
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   GtkWidget *button1, *hbox, *vbox;
 
   /* ja:メインウインドウ */
@@ -135,6 +143,15 @@ reload_dialog (FileType    *ft,
   g_signal_connect (G_OBJECT (check1), "toggled",
                                 G_CALLBACK (reload_dialog_ok_sensitive), NULL);
   /* ja:コンボボックス */
+#if GTK_CHECK_VERSION(2,4,0)
+  combo = gtk_combo_box_new_text ();
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "CR+LF");
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "CR");
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combo), "LF");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), ft->crlf);
+  g_signal_connect (G_OBJECT (combo), "changed",
+                                G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+#else /* not GTK_CHECK_VERSION(2,4,0) */
   glist = g_list_append (NULL, "CR+LF");
   glist = g_list_append (glist, "CR");
   glist = g_list_append (glist, "LF");
@@ -147,6 +164,7 @@ reload_dialog (FileType    *ft,
                                     G_CALLBACK (reload_dialog_activate), ft);
   g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
                                 G_CALLBACK (reload_dialog_ok_sensitive), NULL);
+#endif /* not GTK_CHECK_VERSION(2,4,0) */
   /* ja:文字符号化方式 */
   charset = misc_charset_new ();
   for (i = 0; i < ftnum; i++)
@@ -154,7 +172,7 @@ reload_dialog (FileType    *ft,
   misc_charset_set_charset (MISC_CHARSET (charset), ft->charset);
   g_signal_connect (G_OBJECT (charset), "activate",
                                     G_CALLBACK (reload_dialog_activate), ft);
-  g_signal_connect (G_OBJECT (charset), "changed",
+  g_signal_connect (G_OBJECT (charset), "edited",
                                 G_CALLBACK (reload_dialog_ok_sensitive), NULL);
   /* ja:フレームとボックス */
   hbox = gtk_hbox_new (FALSE, SPACING);
