@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "general.h"
 #include "sigfile.h"
 #include "misc/misc.h"
+#include "misc/misc_mdi.h"
 
 
 /******************************************************************************
@@ -33,16 +34,15 @@ gboolean
 signal_timeout (gpointer data)
 {
   gint page;
-  GdkRectangle rc;
-  TmaidWindow *tmaid;
 
   caret = !caret;
-  page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+  page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
   if (page >= 0)
     {
-      tmaid = g_object_get_data (G_OBJECT
-                (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page)),
-                                                                "user_data");
+      GdkRectangle rc;
+      TmaidWindow *tmaid;
+
+      tmaid = misc_mdi_get_data (MISC_MDI (mdi), page);
       rc.x = (edit_get_align_pos (tmaid, tmaid->cursor.x,
                 tmaid->cursor.y, FALSE) - tmaid->top.x) * tmaid->font_width;
       rc.y = (tmaid->cursor.y - tmaid->top.y) * tmaid->font_height;
@@ -199,27 +199,15 @@ void
 signal_destroy_draw (GtkWidget   *widget,
                      TmaidWindow *tmaid)
 {
-  GList *glist;
-  GtkWidget *menu_shell;
-  LineBuffer *p;
-
-  /* ja:ファイル名を調べる */
-  file_delete_edit (tmaid->file);
-  /* ja:ウインドウメニュー */
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/Window");
-  gtk_container_remove (GTK_CONTAINER (menu_shell), tmaid->menu_item);
   /* ja:メニュー */
-  glist = gtk_container_children (GTK_CONTAINER (notebook));
-  if (g_list_length (glist) <= 1)
+  if (misc_mdi_get_n_pages (MISC_MDI (mdi)) <= 1)
     {
       set_menu_bar (NULL);
       gtk_statusbar_pop (GTK_STATUSBAR (status),
             gtk_statusbar_get_context_id (GTK_STATUSBAR (status), "Status"));
       gtk_label_set_text (GTK_LABEL (label_cursor), "");
     }
-  g_list_free (glist);
   /* ja:メモリを解放する */
-  g_free (tmaid->file);
   g_object_unref (tmaid->layout);
   if (tmaid->timer_id != 0)
     {
@@ -230,6 +218,8 @@ signal_destroy_draw (GtkWidget   *widget,
     tmaid->start = tmaid->start->prev;
   while (tmaid->start)
     {
+      LineBuffer *p;
+
       p = tmaid->start->next;
       g_free (tmaid->start->text);
       g_free (tmaid->start);
@@ -259,8 +249,6 @@ signal_commit (GtkIMContext *im_context,
 {
   gchar *str;
   gint i, leng, length;
-  TmaidHistory *d;
-  GdkPoint select;
 
   length = g_strlen (arg1);
   for (i = 0; i < length; i += leng)
@@ -271,6 +259,9 @@ signal_commit (GtkIMContext *im_context,
     }
   if (i == length)
     {
+      GdkPoint select;
+      TmaidHistory *d;
+
       select = tmaid->select;
       tmaid->cursor.x = edit_get_align_pos
                             (tmaid, tmaid->cursor.x, tmaid->cursor.y, FALSE);
@@ -287,7 +278,8 @@ signal_commit (GtkIMContext *im_context,
       tmaid->undo = d;
       if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
         set_menu_bar (tmaid);
-      tmaid_change_edit (tmaid, TRUE);
+      misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
     }
 #ifndef G_OS_WIN32
   gtk_im_context_get_preedit_string (im_context, &str, NULL, NULL);
@@ -799,13 +791,15 @@ signal_button_press (GtkWidget      *widget,
                     /* ja:貼り付け */
                     d = edit_operation (tmaid,
                                         text, g_strlen (text), FALSE, TRUE);
+                    g_free (text);
                     d->next = tmaid->undo;
                     tmaid->undo = d;
                     if (delete_list(&tmaid->redo) > 0 || !d->next
                                                                 || select.x<0)
                       set_menu_bar (tmaid);
-                    tmaid_change_edit (tmaid, TRUE);
-                    g_free (text);
+                    misc_mdi_set_edited (MISC_MDI (mdi),
+                        misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid),
+                                                                        TRUE);
                   }
                 else
                   {
