@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "sigfile.h"
 #include "sigkey.h"
 #include "misc/misc.h"
+#include "misc/misc_mdi.h"
 
 
 /******************************************************************************
@@ -329,7 +330,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          tmaid_change_edit (tmaid, TRUE);
+          misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
         }
         result=TRUE;
         break;
@@ -368,7 +370,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          tmaid_change_edit (tmaid, TRUE);
+          misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
@@ -401,18 +404,16 @@ signal_key_press (GtkWidget   *widget,
               tmaid->undo = d;
               if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
                 set_menu_bar (tmaid);
-              tmaid_change_edit (tmaid, TRUE);
+              misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
             }
           else
             {
               gint page;
               guint length;
-              GList *glist;
 
-              glist = gtk_container_children (GTK_CONTAINER (notebook));
-              length = g_list_length (glist);
-              g_list_free (glist);
-              page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+              length = misc_mdi_get_n_pages (MISC_MDI (mdi));
+              page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
               if (event->state & GDK_SHIFT_MASK)
                 {
                   if (--page<0)
@@ -423,11 +424,9 @@ signal_key_press (GtkWidget   *widget,
                   if (++page>=length)
                     page=0;
                 }
-              gtk_notebook_set_page (GTK_NOTEBOOK (notebook), page);
+              gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page);
               gtk_widget_grab_focus (((TmaidWindow *)
-                                g_object_get_data (G_OBJECT
-                                (gtk_notebook_get_nth_page (GTK_NOTEBOOK
-                                (notebook), page)), "user_data"))->drawing);
+                        misc_mdi_get_data (MISC_MDI (mdi), page))->drawing);
             }
         }
         result=TRUE;
@@ -507,7 +506,8 @@ signal_key_press (GtkWidget   *widget,
           tmaid->undo = d;
           if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
             set_menu_bar (tmaid);
-          tmaid_change_edit (tmaid, TRUE);
+          misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
@@ -557,7 +557,8 @@ signal_key_press (GtkWidget   *widget,
             tmaid->undo = d;
             if (delete_list(&tmaid->redo) > 0 || !d->next || select.x >= 0)
               set_menu_bar (tmaid);
-            tmaid_change_edit (tmaid, TRUE);
+              misc_mdi_set_edited (MISC_MDI (mdi),
+                    misc_mdi_get_page_from_data (MISC_MDI (mdi), tmaid), TRUE);
         }
         result = TRUE;
         break;
