@@ -25,6 +25,7 @@
 #include "sigmain.h"
 #include "misc/argument.h"
 #include "misc/misc.h"
+#include "misc/misc_history.h"
 #include "misc/misc_mdi.h"
 
 
@@ -101,21 +102,13 @@ signal_style_set (GtkWidget *widget,
 *                                                                             *
 ******************************************************************************/
 void
-signal_activate_menu_history (GtkWidget *widget,
-                              gchar     *file)
+signal_activate_menu_history (GtkWidget   *widget,
+                              const gchar *file)
 {
   file_open_edit (file);
 }
 
 
-void
-signal_destroy_menu_history (GtkWidget *widget,
-                             gchar     *file)
-{
-  g_free (file);
-}
-
-
 /******************************************************************************
 *                                                                             *
 * ja:シグナル/イベント関数群(MDI)                                             *
@@ -308,8 +301,8 @@ signal_selection_recv (GObject   *object,
 
   /* ja:プロセス間通信 */
   /* ja:ファイルの履歴 */
-  arg_h.val = history;
-  arg_h.def = 4;
+  arg_h.val = misc_history_get_num (MISC_HISTORY (history));
+  arg_h.def = MISC_HISTORY_NUM_DEF;
   /* ja:初期のキャレット位置 */
   arg_l.val = 0;
   arg_l.def = 0;
@@ -329,21 +322,7 @@ signal_selection_recv (GObject   *object,
   arg_x.def = FALSE;
   /* ja:コマンドラインの解析 */
   arg_files = arg_analyse (argv, arg_opts);
-  if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
-    {
-      /* ja:履歴の整理 */
-      GList *glist;
-      GtkWidget *menu_shell;
-
-      history = arg_h.val;
-      menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-      glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-      for (i = g_list_length (glist) - 3;
-                            i > history - (history == 0) + MENUFILE - 2; i--)
-        gtk_container_remove (GTK_CONTAINER
-                                    (menu_shell), g_list_nth_data (glist, i));
-      g_list_free (glist);
-    }
+  misc_history_set_num (MISC_HISTORY (history), arg_h.val);
   newfile = arg_n.flag;
   def_width = array[0];
   def_height = array[1];
@@ -382,23 +361,3 @@ signal_delete (GtkWidget *widget,
     }
   return FALSE;
 }
-
-
-void
-signal_destroy_window (GtkWidget *widget,
-                       gpointer   user_data)
-{
-  gint i;
-  GList *glist;
-  GtkWidget *menu_shell;
-
-  memset (history_files, 0, sizeof (gchar *) * 10);
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-  for (i = 0; i < (gint)g_list_length (glist) - MENUFILE - 1; i++)
-    history_files[i] = g_strdup (g_object_get_data
-                        (G_OBJECT (g_list_nth_data (glist, i + MENUFILE - 1)),
-                                                                "user_data"));
-  g_list_free (glist);
-  gtk_main_quit ();
-}
