@@ -44,13 +44,8 @@ void signal_style_set (GtkWidget *widget,
 *                                                                             *
 ******************************************************************************/
 void
-signal_activate_menu_history (GtkWidget *widget,
-                              gchar     *file);
-
-
-void
-signal_destroy_menu_history (GtkWidget *widget,
-                             gchar     *file);
+signal_activate_menu_history (GtkWidget   *widget,
+                              const gchar *file);
 
 
 /******************************************************************************
@@ -128,11 +123,6 @@ signal_delete (GtkWidget *widget,
                gpointer   user_data);
 
 
-void
-signal_destroy_window (GtkWidget *widget,
-                       gpointer   user_data);
-
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
