@@ -36,6 +36,7 @@
 #include "misc/license.h"
 #include "misc/misc_accel.h"
 #include "misc/misc_comm.h"
+#include "misc/misc_history.h"
 #include "misc/misc_mdi.h"
 #include "misc/misc_winmenu.h"
 #include "misc/profile.h"
@@ -45,19 +46,18 @@ gboolean caret = FALSE;             /* ja:キャレットの形 */
 gboolean ins = TRUE;                /* ja:TRUE:挿入,FALSE:上書き */
 gboolean newfile = FALSE;           /* ja:TRUE:新規ファイル,FALSE:なし */
 gboolean second = FALSE;            /* ja:TRUE:新規,FALSE:既存 */
-gchar *history_files[10];           /* ja:ファイルの履歴 */
 gchar *open_path = NULL;            /* ja:開くのパス */
 gchar *save_path = NULL;            /* ja:名前を付けて保存のパス */
 gchar *clipboard_text = NULL;       /* ja:クリップボードのテキスト */
 gint def_width, def_height;         /* ja:デフォルトのウインドウのサイズ */
 gint ftnum = 0;                     /* ja:ファイルタイプの数 */
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
 gint findex = 0;                    /* ja:ファイルタイプのフィルタ */
-#endif /* USE_GTK24 or G_OS_WIN32 */
-gint history = 4;                   /* ja:ファイルの履歴 */
+#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
 gint tcount = 0;                    /* ja:ファイルタイプのカウンタ */
 guint timer_id = 0;                 /* ja:タイマID */
 FileType *ftype = NULL;             /* ja:ファイルタイプ */
+GObject *history;                   /* ja:ファイルの履歴 */
 GdkAtom atom_targets;               /* ja:ターゲット */
 GdkAtom atom_text;                  /* ja:テキスト */
 GdkAtom atom_compound;              /* ja:コンパウンド */
@@ -110,8 +110,7 @@ main (int   argc,
   GObject *accel, *winmenu;
   GtkAccelGroup *accel_group;
   GtkStyle *style;
-  GtkWidget *menu_bar, *menu_shell, *menu_item;
-  GtkWidget *handle, *label, *table, *toolbar, *vbox, *frame;
+  GtkWidget *menu_bar, *handle, *label, *table, *toolbar, *vbox, *frame;
   GtkItemFactoryEntry menu_items[] = {
 {N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
 {N_("/File/_New"),                   "<control>N", command_new,     0,"<Item>"},
@@ -191,25 +190,30 @@ main (int   argc,
 
   def_width = gdk_screen_width () * 2 / 3;
   def_height = gdk_screen_height () * 2 / 3;
-  g_memset (history_files, 0, sizeof (gchar *) * 10);
+
+  /* ja:ファイルの履歴 */
+  history = misc_history_new ();
+
   /* ja:レジストリから読み出す */
   profile = profile_open (NULL);
   if (profile)
     {
+      gint num;
+
       if (!profile_get_value (profile, "tmaid", "license",
             (gpointer)&license, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL))
         license = FALSE;
       if (!profile_get_value(profile, "tmaid", "ftnum",
             (gpointer)&ftnum, sizeof (gint), PROFILE_VALUE_TYPE_INT))
         ftnum = 0;
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
       if (!profile_get_value(profile, "tmaid", "findex",
             (gpointer)&findex, sizeof (gint), PROFILE_VALUE_TYPE_INT))
         findex = 0;
-#endif /* defined USE_GTK24 or defined G_OS_WIN32 */
-      if (!profile_get_value (profile, "tmaid","history",
-            (gpointer)&history, sizeof (gint), PROFILE_VALUE_TYPE_INT))
-        history = 4;
+#endif /* GTK_CHECK_VERSION(2,4,0) or defined G_OS_WIN32 */
+      if (profile_get_value (profile, "tmaid", "history",
+            (gpointer)&num, sizeof (gint), PROFILE_VALUE_TYPE_INT))
+        misc_history_set_num (MISC_HISTORY (history), num);
       if (!profile_get_value (profile, "tmaid", "newfile",
             (gpointer)&newfile, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL))
         newfile = FALSE;
@@ -234,21 +238,19 @@ main (int   argc,
                 ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
       g_free (utf8str);
       /* ja:ファイルの履歴 */
-      for (i = 0; i < history; i++)
+      for (i = misc_history_get_num (MISC_HISTORY (history)) - 1; i >= 0; i--)
         {
           key = g_strdup_printf ("history%d", i);
           utf8str = profile_get_string (profile, "tmaid", key);
-          history_files[i] = utf8str
-                ? g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL) : NULL;
-          g_free (utf8str);
           g_free (key);
-          if (!history_files[i])
-            break;
-          if (*history_files[i] == '\0')
+          if (utf8str)
             {
-              g_free (history_files[i]);
-              history_files[i] = NULL;
-              break;
+              gchar *file;
+
+              file = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
+              g_free (utf8str);
+              misc_history_add_file (MISC_HISTORY (history), file);
+              g_free (file);
             }
         }
       /* ja:検索 */
@@ -501,8 +503,8 @@ main (int   argc,
 {NULL,      '\0', NULL,           NULL,                 0,                   NULL}};
 
     /* ja:ファイルの履歴 */
-    arg_h.val = history;
-    arg_h.def = 4;
+    arg_h.val = misc_history_get_num (MISC_HISTORY (history));
+    arg_h.def = MISC_HISTORY_NUM_DEF;
     /* ja:初期のキャレット位置 */
     arg_l.val = init_line;
     arg_l.def = 0;
@@ -529,8 +531,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
     /* ja:ヘルプ */
     arg_q.str = TMAID_COPYRIGHT_NOTICE"\n\n";
     arg_files = arg_analyse (argv, arg_opts);
-    if (0 <= arg_h.val && arg_h.val <= 10)
-      history = arg_h.val;
+    misc_history_set_num (MISC_HISTORY (history), arg_h.val);
     if (arg_l.val >= 0)
       init_line = arg_l.val;
     def_width = array[0];
@@ -564,7 +565,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
   g_signal_connect (G_OBJECT(window), "delete-event",
                                             G_CALLBACK (signal_delete), NULL);
   g_signal_connect (G_OBJECT (window), "destroy",
-                                    G_CALLBACK (signal_destroy_window), NULL);
+                                            G_CALLBACK (gtk_main_quit), NULL);
   gtk_widget_realize (window);
   /* en:Drag and Drop */
   gtk_drag_dest_set (window, GTK_DEST_DEFAULT_MOTION
@@ -615,6 +616,11 @@ TMAID_COPYRIGHT_NOTICE"\n"
                         sizeof (menu_items) / sizeof (GtkItemFactoryEntry),
                                                             menu_items, NULL);
   menu_bar = gtk_item_factory_get_widget (ifactory_menu, "<main>");
+  /* ja:ファイルの履歴 */
+  misc_history_set_menu (MISC_HISTORY (history),
+    gtk_item_factory_get_widget (ifactory_menu, "<main>/File"), MENUFILE - 2);
+  g_signal_connect (MISC_HISTORY (history), "activate",
+                            G_CALLBACK (signal_activate_menu_history), NULL);
   /* ja:ウインドウメニュー */
   winmenu = misc_winmenu_new ();
   misc_winmenu_set_mdi (MISC_WINMENU (winmenu), MISC_MDI (mdi));
@@ -679,23 +685,6 @@ TMAID_COPYRIGHT_NOTICE"\n"
   gtk_box_pack_end (GTK_BOX (vbox), table, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
-  /* ja:ファイルの履歴 */
-  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-  for (i = 0; i < history && history_files[i]; i++)
-    {
-      utf8str = g_filename_to_utf8 (history_files[i], -1, NULL, NULL, NULL);
-      menu_item = gtk_menu_item_new_with_label (utf8str);
-      g_free (utf8str);
-      g_signal_connect (G_OBJECT (menu_item), "activate",
-                G_CALLBACK (signal_activate_menu_history), history_files[i]);
-      g_signal_connect (G_OBJECT (menu_item), "destroy",
-                G_CALLBACK (signal_destroy_menu_history), history_files[i]);
-      g_object_set_data (G_OBJECT (menu_item), "user_data", history_files[i]);
-      gtk_menu_insert (GTK_MENU (menu_shell), menu_item, i + MENUFILE - 1);
-    }
-  if (i > 0)
-    gtk_menu_insert (GTK_MENU (menu_shell), gtk_menu_item_new (),
-                                                            i + MENUFILE - 1);
   /* ja:タイマ */
   timer_id = g_timeout_add (500, signal_timeout, NULL);
 
@@ -758,16 +747,20 @@ TMAID_COPYRIGHT_NOTICE"\n"
   profile = profile_open (NULL);
   if (profile)
     {
+      gint num;
+      GList *glist;
+
+      num = misc_history_get_num (MISC_HISTORY (history));
       profile_set_value (profile, "tmaid", "license",
             (gpointer)&license, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL);
       profile_set_value (profile, "tmaid", "ftnum",
             (gpointer)&ftnum, sizeof (gint), PROFILE_VALUE_TYPE_INT);
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
       profile_set_value (profile, "tmaid", "findex",
             (gpointer)&findex, sizeof (gint), PROFILE_VALUE_TYPE_INT);
-#endif /* USE_GTK24 or G_OS_WIN32 */
+#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
       profile_set_value (profile, "tmaid", "history",
-            (gpointer)&history, sizeof (gint), PROFILE_VALUE_TYPE_INT);
+            (gpointer)&num, sizeof (gint), PROFILE_VALUE_TYPE_INT);
       profile_set_value (profile, "tmaid", "newfile",
             (gpointer)&newfile, sizeof (gboolean), PROFILE_VALUE_TYPE_BOOL);
       profile_set_value (profile, "tmaid", "second",
@@ -803,10 +796,11 @@ TMAID_COPYRIGHT_NOTICE"\n"
             }
         }
       /* ja:ファイルの履歴 */
-      for (i = 0; i < history && history_files[i] != NULL; i++)
+      glist = misc_history_get_file (MISC_HISTORY (history));
+      for (i = 0; i < g_list_length (glist); i++)
         {
           key = g_strdup_printf ("history%d", i);
-          utf8str = g_filename_to_utf8 (history_files[i], -1,
+          utf8str = g_filename_to_utf8 (g_list_nth_data (glist, i), -1,
                                                             NULL, NULL, NULL);
           if (utf8str)
             {
@@ -817,7 +811,8 @@ TMAID_COPYRIGHT_NOTICE"\n"
             }
           g_free (key);
         }
-      while (i < 10)
+      g_list_free (glist);
+      while (i <= MISC_HISTORY_NUM_MAX)
         {
           key = g_strdup_printf ("history%d", i++);
           profile_delete_key (profile, "tmaid", key);
@@ -1026,8 +1021,6 @@ TMAID_COPYRIGHT_NOTICE"\n"
     g_free (find_text[i]);
   for (i = 0; i < replace_num; i++)
     g_free (replace_text[i]);
-  for (i = 0; i < history; i++)
-    g_free (history_files[i]);
   for (i = 0; i < ftnum; i++)
     {
       g_free (ftype[i].text);
