@@ -117,19 +117,18 @@ extern gboolean caret;                  /* ja:キャレットの形 */
 extern gboolean ins;                    /* ja:TRUE:挿入,FALSE:上書き */
 extern gboolean newfile;                /* ja:TRUE:新規ファイル,FALSE:なし */
 extern gboolean second;                 /* ja:TRUE:新規,FALSE:既存 */
-extern gchar *history_files[10];        /* ja:ファイルの履歴 */
 extern gchar *open_path;                /* ja:開くのパス */
 extern gchar *save_path;                /* ja:名前を付けて保存のパス */
 extern gchar *clipboard_text;           /* ja:クリップボードのテキスト */
 extern gint def_width, def_height;      /* ja:デフォルトのウインドウのサイズ */
 extern gint ftnum;                      /* ja:ファイルタイプの数 */
-#if defined USE_GTK24 || defined G_OS_WIN32
+#if GTK_CHECK_VERSION(2,4,0) || defined G_OS_WIN32
 extern gint findex;                     /* ja:ファイルタイプのフィルタ */
-#endif /* USE_GTK24 or G_OS_WIN32 */
-extern gint history;                    /* ja:ファイルの履歴 */
+#endif /* GTK_CHECK_VERSION(2,4,0) or G_OS_WIN32 */
 extern gint tcount;                     /* ja:ファイルタイプのカウンタ */
 extern guint timer_id;                  /* ja:タイマID */
 extern FileType *ftype;                 /* ja:ファイルタイプ */
+extern GObject *history;                /* ja:ファイルの履歴 */
 extern GdkAtom atom_targets;            /* ja:ターゲット */
 extern GdkAtom atom_text;               /* ja:テキスト */
 extern GdkAtom atom_compound;           /* ja:コンパウンド */
